<?php
/**
 * Created by PhpStorm.
 * User: crose
 * Date: 17.02.19
 * Time: 15:40
 */

namespace qfq;

use qfq;

require_once(__DIR__ . '/../core/QuickFormQuery.php');
require_once(__DIR__ . '/../core/exceptions/UserFormException.php');
require_once(__DIR__ . '/../core/exceptions/CodeException.php');
require_once(__DIR__ . '/../core/exceptions/DbException.php');

$restId = array();
$restForm = array();

$status = 'HTTP/1.0 409 Bad Request';
$data = array();

try {
    try {
        $form = OnString::splitPathInfoToIdForm($_SERVER['PATH_INFO'], $restId, $restForm);

        // get latest `ìd`
        $id = end($restId);

        // Fake Bodytext setup
        $bodytext = TYPO3_RECORD_ID . '=' . $id . PHP_EOL;
        $bodytext .= TYPO3_FORM . '=' . $form . PHP_EOL;

        $method = $_SERVER['REQUEST_METHOD'];
        switch ($method) {
            case REQUEST_METHOD_GET:
                break;
            case REQUEST_METHOD_POST:
                if ($id != 0) {
                    throw new UserFormException('Method POST needs no id or id=0', ERROR_REST_INVALID_ID);
                }
                $data = json_decode(file_get_contents('php://input'), true);
                break;
            case REQUEST_METHOD_PUT:
                if ($id == 0) {
                    throw new UserFormException('Method PUT needs an id>0', ERROR_REST_INVALID_ID);
                }
                $data = json_decode(file_get_contents('php://input'), true);
                break;
            case REQUEST_METHOD_DELETE:
                if ($id == 0) {
                    throw new UserFormException('Method DELETE needs an id>0', ERROR_REST_INVALID_ID);
                }
                break;
            default:
                break;
        }

        if ($data === null) {
            throw new NotAcceptableResponseException(
                json_encode([ERROR_MESSAGE_TO_USER => 'Invalid JSON',
                    ERROR_MESSAGE_SUPPORT => json_last_error_msg()]), ERROR_INVALID_VALUE);
        }

        if(!empty($data)){
            $_POST = $data;
        }

        $qfq = new QuickFormQuery(['bodytext' => $bodytext]);
        $answer = $qfq->rest($restId, $restForm);
        $status = 'HTTP/1.0 200 OK';

    } catch (qfq\CodeException $e) {
        $answer[API_MESSAGE] = $e->formatMessage();
        $status=$e->getHttpStatus();

    } catch (qfq\UserFormException $e) {
        $answer[API_MESSAGE] = $e->formatMessage();
        $status=$e->getHttpStatus();

    } catch (qfq\DbException $e) {
        $answer[API_MESSAGE] = $e->formatMessage();
        $status=$e->getHttpStatus();
    }

} catch (\Exception $e) {
    $answer[API_MESSAGE] = "Generic Exception: " . $e->getMessage();
}

header($status);
header("Content-Type: application/json");
echo json_encode($answer);
